Class: Portless::RouteStore::Route
- Inherits:
-
Struct
- Object
- Struct
- Portless::RouteStore::Route
- Defined in:
- lib/portless/route_store.rb
Instance Attribute Summary collapse
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#lan ⇒ Object
Returns the value of attribute lan.
-
#ngrok ⇒ Object
Returns the value of attribute ngrok.
-
#pid ⇒ Object
Returns the value of attribute pid.
-
#port ⇒ Object
Returns the value of attribute port.
-
#tailscale ⇒ Object
Returns the value of attribute tailscale.
Instance Method Summary collapse
-
#alias? ⇒ Boolean
pid 0 = static alias (never reaped).
-
#lan? ⇒ Boolean
Did this route opt into being served to LAN clients (
run --lan)? The proxy refuses to serve anything else off-loopback.
Instance Attribute Details
#hostname ⇒ Object
Returns the value of attribute hostname
12 13 14 |
# File 'lib/portless/route_store.rb', line 12 def hostname @hostname end |
#lan ⇒ Object
Returns the value of attribute lan
12 13 14 |
# File 'lib/portless/route_store.rb', line 12 def lan @lan end |
#ngrok ⇒ Object
Returns the value of attribute ngrok
12 13 14 |
# File 'lib/portless/route_store.rb', line 12 def ngrok @ngrok end |
#pid ⇒ Object
Returns the value of attribute pid
12 13 14 |
# File 'lib/portless/route_store.rb', line 12 def pid @pid end |
#port ⇒ Object
Returns the value of attribute port
12 13 14 |
# File 'lib/portless/route_store.rb', line 12 def port @port end |
#tailscale ⇒ Object
Returns the value of attribute tailscale
12 13 14 |
# File 'lib/portless/route_store.rb', line 12 def tailscale @tailscale end |
Instance Method Details
#alias? ⇒ Boolean
pid 0 = static alias (never reaped)
13 |
# File 'lib/portless/route_store.rb', line 13 def alias? = pid.to_i.zero? # pid 0 = static alias (never reaped) |
#lan? ⇒ Boolean
Did this route opt into being served to LAN clients (run --lan)?
The proxy refuses to serve anything else off-loopback.
17 |
# File 'lib/portless/route_store.rb', line 17 def lan? = !!lan |